@@ -3,8 +3,8 @@ package cli
 import (
 	"fmt"
 
-	"github.com/jandedobbeleer/oh-my-posh/src/engine"
-	"github.com/jandedobbeleer/oh-my-posh/src/platform"
+	"github.com/jandedobbeleer/oh-my-posh/src/prompt"
+	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
 
 	"github.com/spf13/cobra"
 )
@@ -12,7 +12,8 @@ import (
 var (
 	pwd           string
 	pswd          string
-	exitCode      int
+	status        int
+	pipestatus    string
 	timing        float64
 	stackCount    int
 	terminalWidth int
@@ -22,7 +23,8 @@ var (
 	command      string
 	shellVersion string
 	plain        bool
-	noExitCode   bool
+	noStatus     bool
+	column       int
 )
 
 // printCmd represents the prompt command
@@ -47,11 +49,12 @@ var printCmd = &cobra.Command{
 			return
 		}
 
-		flags := &platform.Flags{
-			Config:        config,
+		flags := &runtime.Flags{
+			Config:        configFlag,
 			PWD:           pwd,
 			PSWD:          pswd,
-			ErrorCode:     exitCode,
+			ErrorCode:     status,
+			PipeStatus:    pipestatus,
 			ExecutionTime: timing,
 			StackCount:    stackCount,
 			TerminalWidth: terminalWidth,
@@ -61,42 +64,44 @@ var printCmd = &cobra.Command{
 			Plain:         plain,
 			Primary:       args[0] == "primary",
 			Cleared:       cleared,
-			NoExitCode:    noExitCode,
-			Version:       cliVersion,
+			NoExitCode:    noStatus,
+			Column:        column,
 		}
 
-		eng := engine.New(flags)
+		eng := prompt.New(flags)
 		defer eng.Env.Close()
 
 		switch args[0] {
 		case "debug":
-			fmt.Print(eng.ExtraPrompt(engine.Debug))
+			fmt.Print(eng.ExtraPrompt(prompt.Debug))
 		case "primary":
 			fmt.Print(eng.Primary())
 		case "secondary":
-			fmt.Print(eng.ExtraPrompt(engine.Secondary))
+			fmt.Print(eng.ExtraPrompt(prompt.Secondary))
 		case "transient":
-			fmt.Print(eng.ExtraPrompt(engine.Transient))
+			fmt.Print(eng.ExtraPrompt(prompt.Transient))
 		case "right":
 			fmt.Print(eng.RPrompt())
 		case "tooltip":
 			fmt.Print(eng.Tooltip(command))
 		case "valid":
-			fmt.Print(eng.ExtraPrompt(engine.Valid))
+			fmt.Print(eng.ExtraPrompt(prompt.Valid))
 		case "error":
-			fmt.Print(eng.ExtraPrompt(engine.Error))
+			fmt.Print(eng.ExtraPrompt(prompt.Error))
 		default:
 			_ = cmd.Help()
 		}
 	},
 }
 
-func init() { //nolint:gochecknoinits
+func init() {
 	printCmd.Flags().StringVar(&pwd, "pwd", "", "current working directory")
 	printCmd.Flags().StringVar(&pswd, "pswd", "", "current working directory (according to pwsh)")
 	printCmd.Flags().StringVar(&shellName, "shell", "", "the shell to print for")
 	printCmd.Flags().StringVar(&shellVersion, "shell-version", "", "the shell version")
-	printCmd.Flags().IntVarP(&exitCode, "error", "e", 0, "last exit code")
+	printCmd.Flags().IntVar(&status, "status", 0, "last known status code")
+	printCmd.Flags().BoolVar(&noStatus, "no-status", false, "no valid status code (cancelled or no command yet)")
+	printCmd.Flags().StringVar(&pipestatus, "pipestatus", "", "the PIPESTATUS array")
 	printCmd.Flags().Float64Var(&timing, "execution-time", 0, "timing of the last command")
 	printCmd.Flags().IntVarP(&stackCount, "stack-count", "s", 0, "number of locations on the stack")
 	printCmd.Flags().IntVarP(&terminalWidth, "terminal-width", "w", 0, "width of the terminal")
@@ -104,6 +109,9 @@ func init() { //nolint:gochecknoinits
 	printCmd.Flags().BoolVarP(&plain, "plain", "p", false, "plain text output (no ANSI)")
 	printCmd.Flags().BoolVar(&cleared, "cleared", false, "do we have a clear terminal or not")
 	printCmd.Flags().BoolVar(&eval, "eval", false, "output the prompt for eval")
-	printCmd.Flags().BoolVar(&noExitCode, "no-exit-code", false, "no valid exit code (cancelled or no command yet)")
+	printCmd.Flags().IntVar(&column, "column", 0, "the column position of the cursor")
+	// Deprecated flags
+	printCmd.Flags().IntVarP(&status, "error", "e", 0, "last exit code")
+	printCmd.Flags().BoolVar(&noStatus, "no-exit-code", false, "no valid exit code (cancelled or no command yet)")
 	RootCmd.AddCommand(printCmd)
 }
