@@ -6,36 +6,10 @@ import (
 	"os"
 	"testing"
 
-	"github.com/jandedobbeleer/oh-my-posh/src/mock"
-	"github.com/jandedobbeleer/oh-my-posh/src/platform"
-	"github.com/jandedobbeleer/oh-my-posh/src/properties"
-
+	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
 	"github.com/stretchr/testify/assert"
 )
 
-type mockedLanguageParams struct {
-	cmd           string
-	versionParam  string
-	versionOutput string
-	extension     string
-}
-
-func getMockedLanguageEnv(params *mockedLanguageParams) (*mock.MockedEnvironment, properties.Map) {
-	env := new(mock.MockedEnvironment)
-	env.On("HasCommand", params.cmd).Return(true)
-	env.On("RunCommand", params.cmd, []string{params.versionParam}).Return(params.versionOutput, nil)
-	env.On("HasFiles", params.extension).Return(true)
-	env.On("Pwd").Return("/usr/home/project")
-	env.On("Home").Return("/usr/home")
-	env.On("TemplateCache").Return(&platform.TemplateCache{
-		Env: make(map[string]string),
-	})
-	props := properties.Map{
-		properties.FetchVersion: true,
-	}
-	return env, props
-}
-
 func TestGolang(t *testing.T) {
 	cases := []struct {
 		Case                  string
@@ -47,7 +21,7 @@ func TestGolang(t *testing.T) {
 	}{
 		{Case: "Go 1.15", ExpectedString: "1.15.8", Version: "go version go1.15.8 darwin/amd64"},
 		{Case: "Go 1.16", ExpectedString: "1.16", Version: "go version go1.16 darwin/amd64"},
-		{Case: "go.mod 1.20", ParseModFile: true, HasModFileInParentDir: true, ExpectedString: "1.20"},
+		{Case: "go.mod 1.22.3", ParseModFile: true, HasModFileInParentDir: true, ExpectedString: "1.22.3"},
 		{Case: "no go.mod file fallback", ParseModFile: true, ExpectedString: "1.16", Version: "go version go1.16 darwin/amd64"},
 		{
 			Case:                  "invalid go.mod file fallback",
@@ -68,7 +42,7 @@ func TestGolang(t *testing.T) {
 		env, props := getMockedLanguageEnv(params)
 		if tc.ParseModFile {
 			props[ParseModFile] = tc.ParseModFile
-			fileInfo := &platform.FileInfo{
+			fileInfo := &runtime.FileInfo{
 				Path:         "../go.mod",
 				ParentFolder: "./",
 				IsDir:        false,
